@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use autodie;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Test::Vars 0.008;
 use Path::Class qw( dir );
@@ -63,7 +63,7 @@ sub validate_source {
     return test_vars(
         $file,
         \&_result_handler,
-        %{ $self->_ignore_for_package->{$package} // {} },
+        %{ $self->_ignore_for_package->{$package} || {} },
     );
 }
 
@@ -144,7 +144,7 @@ Code::TidyAll::Plugin::Test::Vars - Provides Test::Vars plugin for Code::TidyAll
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -194,7 +194,7 @@ Greg Oschwald <goschwald@maxmind.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by MaxMind, Inc..
+This software is copyright (c) 2015 - 2016 by MaxMind, Inc..
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
